@@ -1,5 +1,5 @@
 /* 
- * $Id: citserver.c 6366 2008-06-03 03:41:51Z ajc $
+ * $Id: citserver.c 6452 2008-07-17 19:03:00Z davew $
  *
  * Main source module for the Citadel server
  *
@@ -984,7 +984,7 @@ void begin_session(struct CitContext *con)
 	con->dl_is_net = 0;
 
 	con->nologin = 0;
-	if ((config.c_maxsessions > 0)&&(num_sessions > config.c_maxsessions)) {
+	if (((config.c_maxsessions > 0)&&(num_sessions > config.c_maxsessions)) || CtdlWantSingleUser()) {
 		con->nologin = 1;
 	}
 
