@@ -1,5 +1,5 @@
 /*
- * $Id: serv_expire.c 6385 2008-06-16 11:55:14Z davew $
+ * $Id: serv_expire.c 6571 2008-09-07 14:49:53Z davew $
  *
  * This module handles the expiry of old messages and the purging of old users.
  *
@@ -121,10 +121,9 @@ int messages_purged;
 int users_not_purged;
 char *users_corrupt_msg = NULL;
 char *users_zero_msg = NULL;
-
 struct ctdlroomref *rr = NULL;
-
 extern struct CitContext *ContextList;
+int force_purge_now = 0;			/* set to nonzero to force a run right now */
 
 
 /*
@@ -152,6 +151,10 @@ void GatherPurgeMessages(struct ctdlroom *qrbuf, void *data) {
 	if (epbuf.expire_mode == EXPIRE_NEXTLEVEL) return;
 	if (epbuf.expire_mode == EXPIRE_MANUAL) return;
 
+	/* Don't purge messages containing system configuration, dumbass. */
+	if (!strcasecmp(qrbuf->QRname, SYSCONFIGROOM)) return;
+
+	/* Ok, we got this far ... now let's see what's in the room */
         cdbfr = cdb_fetch(CDB_MSGLISTS, &qrbuf->QRnumber, sizeof(long));
 
         if (cdbfr != NULL) {
@@ -167,6 +170,7 @@ void GatherPurgeMessages(struct ctdlroom *qrbuf, void *data) {
 		return;
 	}
 
+
 	/* If the room is set to expire by count, do that */
 	if (epbuf.expire_mode == EXPIRE_NUMMSGS) {
 		if (num_msgs > epbuf.expire_value) {
@@ -290,6 +294,7 @@ void DoPurgeRooms(struct ctdlroom *qrbuf, void *data) {
 		if (qrbuf->QRflags & QR_PERMANENT) return;
 		if (qrbuf->QRflags & QR_DIRECTORY) return;
 		if (qrbuf->QRflags & QR_NETWORK) return;
+		if (qrbuf->QRflags2 & QR2_SYSTEM) return;
 		if (!strcasecmp(qrbuf->QRname, SYSCONFIGROOM)) return;
 		if (is_noneditable(qrbuf)) return;
 
@@ -410,6 +415,10 @@ void do_user_purge(struct ctdluser *us, void *data) {
 
 	/* The default rule is to not purge. */
 	purge = 0;
+	
+	/* don't attempt to purge system users. */
+	if (!strncmp(us->fullname, "SYS_", 4))
+		goto skip_all_this;
 
 	/* If the user hasn't called in two months and expiring of accounts is turned on, his/her account
 	 * has expired, so purge the record.
@@ -446,13 +455,22 @@ void do_user_purge(struct ctdluser *us, void *data) {
 	 */
 	if (us->timescalled < 0) purge = 1;
 
-	/* User number 0, as well as any negative user number, is
+	/* any negative user number, is
 	 * also impossible.
 	 */
 	if (us->usernum < 0L) purge = 1;
 	
 	/** Don't purge user 0. That user is there for the system */
-	if (us->usernum == 0) purge = 0;
+	if (us->usernum == 0L)
+	{
+		/* FIXME: Temporary log message. Until we do unauth access with user 0 we should
+		 * try to get rid of all user 0 occurences. Many will be remnants from old code so
+		 * we will need to try and purge them from users data bases.Some will not have names but
+		 * those with names should be purged.
+		 */
+		CtdlLogPrintf(CTDL_DEBUG, "Auto purger found a user 0 with name \"%s\"\n", us->fullname);
+		// purge = 0;
+	}
 	
 	/* If the user has no full name entry then we can't purge them
 	 * since the actual purge can't find them.
@@ -461,11 +479,6 @@ void do_user_purge(struct ctdluser *us, void *data) {
 	if (IsEmptyStr(us->fullname))
 	{
 		purge = 0;
-/*
- ** Keeping this block of code for later referance.
- * We don't actually want to send the user 0 messages as part of the purger cycle
- * But we might want to use some of this code to do a user database integrity check
- * some time in the future.
 		
 		if (us->usernum > 0L)
 		{
@@ -474,43 +487,19 @@ void do_user_purge(struct ctdluser *us, void *data) {
 			{
 				users_corrupt_msg = malloc(SIZ);
 				strcpy(users_corrupt_msg, "The auto-purger found the following user numbers with no name.\n"
-				"If the user number is 0 you should report this to the Citadel development\n"
-				"team either by a bugzilla report at http://bugzilla.citadel.org or\n"
-				"posting a message in the Citadel Support room on Uncensored at\n"
-				"https://uncensored.citadel.org You should make it clear that you have seen a\n"
-				"user 0 messages in the Aide room which means a module has not named its\n"
-				"private context.\n"
-				"Unfortunately the auto-purger is not yet able to fix this problem.\n"
-				"This problem is not considered serious since a user with no name can\n"
-				"not log in.\n");
+				"The system has no way to purge user with no name and should not be able to\n"
+				"create them either.\n"
+				"This indicates corruption of the user DB or possibly a bug.\n"
+				"It may be a good idea to restore your DB from a backup.\n");
 			}
 		
-			users_corrupt_msg=realloc(users_corrupt_msg, strlen(users_corrupt_msg)+SIZ);
-			snprintf(&users_corrupt_msg[strlen(users_corrupt_msg)], SIZ, " %ld\n", us->usernum);
+			users_corrupt_msg=realloc(users_corrupt_msg, strlen(users_corrupt_msg)+30);
+			snprintf(&users_corrupt_msg[strlen(users_corrupt_msg)], 29, " %ld\n", us->usernum);
 		}
-		else if (us->usernum == 0L)
-		{
-			purge=0;
-			if (users_zero_msg == NULL)
-			{
-				users_zero_msg = malloc(SIZ);
-				strcpy(users_zero_msg, "The auto-purger found a user with a user number of 0 but no name.\n"
-				"This is the result of a bug where a private contaxt has been created but\n"
-				"not named.\n\n"
-				"Please report this to the Citadel development team either by a bugzilla\n"
-				"report at http://bugzilla.citadel.org or by posting a message in the\n"
-				"Citadel Support room on Uncensored at https://uncensored.citadel.org\n"
-				"You should make it clear that you have seen a user 0 messages in the\n"
-				"Aide room which means a module has not named its private context.\n\n"
-				"This problem is not considered serious since it does not constitute a\n"
-				"security risk and should not impare system operation.\n"
-				);
-			}
-		}
-*/
 	}
 
-
+skip_all_this:
+		
 	if (purge == 1) {
 		pptr = (struct PurgeList *) malloc(sizeof(struct PurgeList));
 		pptr->next = UserPurgeList;
@@ -862,7 +851,7 @@ void *purge_databases(void *args)
 
 	CtdlLogPrintf(CTDL_DEBUG, "Auto-purger_thread() initializing\n");
 
-	CtdlFillPrivateContext(&purgerCC, "purger");
+	CtdlFillSystemContext(&purgerCC, "purger");
 	citthread_setspecific(MyConKey, (void *)&purgerCC );
 
         while (!CtdlThreadCheckStop()) {
@@ -872,7 +861,10 @@ void *purge_databases(void *args)
                  */
                 now = time(NULL);
                 localtime_r(&now, &tm);
-                if ((tm.tm_hour != config.c_purge_hour) || ((now - last_purge) < 43200)) {
+                if (
+			((tm.tm_hour != config.c_purge_hour) || ((now - last_purge) < 43200))
+			&& (force_purge_now == 0)
+		) {
                         CtdlThreadSleep(60);
                         continue;
                 }
@@ -932,6 +924,7 @@ void *purge_databases(void *args)
 		{
                 	CtdlLogPrintf(CTDL_INFO, "Auto-purger: finished.\n");
 	                last_purge = now;	/* So we don't do it again soon */
+			force_purge_now = 0;
 		}
 		else
                 	CtdlLogPrintf(CTDL_INFO, "Auto-purger: STOPPED.\n");
@@ -1021,6 +1014,14 @@ void cmd_fsck(char *argbuf) {
 }
 
 
+/*
+ * Manually initiate a run of The Dreaded Auto-Purger (tm)
+ */
+void cmd_tdap(char *argbuf) {
+	if (CtdlAccessCheck(ac_aide)) return;
+	force_purge_now = 1;
+	cprintf("%d Manually initiating a purger run now.\n", CIT_OK);
+}
 
 
 /*****************************************************************************/
@@ -1030,9 +1031,10 @@ CTDL_MODULE_INIT(expire)
 	if (!threading)
 	{
 		CtdlRegisterProtoHook(cmd_fsck, "FSCK", "Check message ref counts");
+		CtdlRegisterProtoHook(cmd_tdap, "TDAP", "Manually initiate auto-purger");
 	}
 	else
 		CtdlThreadCreate("Auto Purger", CTDLTHREAD_BIGSTACK, purge_databases, NULL);
 	/* return our Subversion id for the Log */
-	return "$Id: serv_expire.c 6385 2008-06-16 11:55:14Z davew $";
+	return "$Id: serv_expire.c 6571 2008-09-07 14:49:53Z davew $";
 }
