@@ -1,5 +1,5 @@
 /*
- * $Id: imap_misc.c 6324 2008-05-24 14:37:02Z dothebart $
+ * $Id: imap_misc.c 6453 2008-07-17 19:50:29Z ajc $
  *
  *
  */
@@ -233,77 +233,6 @@ void imap_uidcopy(int num_parms, char *parms[]) {
 }
 
 
-/*
- * Poll for instant messages (yeah, we can do this in IMAP ... I think)
- */
-void imap_print_instant_messages(void) {
-	struct ExpressMessage *ptr, *holdptr;
-	char *dumpomatic = NULL;
-	char tmp[SIZ];
-	int i;
-	size_t size, size2;
-	struct tm stamp;
-
-	if (CC->FirstExpressMessage == NULL) {
-		return;
-	}
-	begin_critical_section(S_SESSION_TABLE);
-	ptr = CC->FirstExpressMessage;
-	CC->FirstExpressMessage = NULL;
-	end_critical_section(S_SESSION_TABLE);
-
-	while (ptr != NULL) {
-		localtime_r(&(ptr->timestamp), &stamp);
-		size = strlen(ptr->text) + SIZ;
-		dumpomatic = malloc(size);
-		strcpy(dumpomatic, "");
-		if (ptr->flags && EM_BROADCAST)
-			strcat(dumpomatic, "Broadcast message ");
-		else if (ptr->flags && EM_CHAT)
-			strcat(dumpomatic, "Chat request ");
-		else if (ptr->flags && EM_GO_AWAY)
-			strcat(dumpomatic, "Please logoff now, as requested ");
-		else
-			strcat(dumpomatic, "Message ");
-
-		/* Timestamp.  Can this be improved? */
-		if (stamp.tm_hour == 0 || stamp.tm_hour == 12)
-			sprintf(tmp, "at 12:%02d%cm",
-				stamp.tm_min, 
-				stamp.tm_hour ? 'p' : 'a');
-		else if (stamp.tm_hour > 12)		/* pm */
-			sprintf(tmp, "at %d:%02dpm",
-				stamp.tm_hour - 12,
-				stamp.tm_min);
-		else					/* am */
-			sprintf(tmp, "at %d:%02dam",
-				stamp.tm_hour, stamp.tm_min);
-		strcat(dumpomatic, tmp);
-
-		size2 = strlen(dumpomatic);
-		snprintf(&dumpomatic[size2], size - size2,
-			" from %s:\n", ptr->sender);
-		if (ptr->text != NULL)
-			strcat(dumpomatic, ptr->text);
-
-		holdptr = ptr->next;
-		if (ptr->text != NULL) free(ptr->text);
-		free(ptr);
-		ptr = holdptr;
-
-		for (i=0; dumpomatic[i]; ++i) {
-			if (!isprint(dumpomatic[i])) dumpomatic[i] = ' ';
-			if (dumpomatic[i]=='\\') dumpomatic[i]='/';
-			if (dumpomatic[i]=='\"') dumpomatic[i]='\'';
-		}
-
-		cprintf("* OK [ALERT] %s\r\n", dumpomatic);
-		free(dumpomatic);
-	}
-	cprintf("000\n");
-}
-
-
 /*
  * imap_do_append_flags() is called by imap_append() to set any flags that
  * the client specified at append time.
