@@ -1,5 +1,5 @@
 /*
- * $Id: serv_imap.c 6333 2008-05-28 00:26:36Z davew $ 
+ * $Id: serv_imap.c 6453 2008-07-17 19:50:29Z ajc $ 
  *
  * IMAP server for the Citadel system
  * Copyright (C) 2000-2007 by Art Cancro and others.
@@ -498,6 +498,12 @@ void imap_greeting(void)
 	IMAP->cached_rfc822_msgnum = (-1);
 	IMAP->cached_rfc822_withbody = 0;
 
+	if (CC->nologin)
+	{
+		cprintf("* BYE; Server busy, try later\r\n");
+		CC->kill_me = 1;
+		return;
+	}
 	cprintf("* OK [");
 	imap_output_capability_string();
 	cprintf("] %s IMAP4rev1 %s ready\r\n", config.c_fqdn, CITADEL);
@@ -1418,13 +1424,14 @@ void imap_command_loop(void)
 	}
 	
 	if (untagged_ok) {
-		imap_print_instant_messages();
-	
+
+		/* we can put any additional untagged stuff right here in the future */
+
 		/*
 		 * Before processing the command that was just entered... if we happen
 		 * to have a folder selected, we'd like to rescan that folder for new
 		 * messages, and for deletions/changes of existing messages.  This
-		 * could probably be optimized somehow, but IMAP sucks...
+		 * could probably be optimized better with some deep thought...
 		 */
 		if (IMAP->selected) {
 			imap_rescan_msgids();
@@ -1452,7 +1459,7 @@ void imap_command_loop(void)
 
 	else if (!strcasecmp(parms[1], "LOGOUT")) {
 		if (IMAP->selected) {
-			imap_do_expunge();	/* yes, we auto-expunge */
+			imap_do_expunge();	/* yes, we auto-expunge at logout */
 		}
 		cprintf("* BYE %s logging out\r\n", config.c_fqdn);
 		cprintf("%s OK Citadel IMAP session ended.\r\n",
@@ -1652,5 +1659,5 @@ CTDL_MODULE_INIT(imap)
 	}
 	
 	/* return our Subversion id for the Log */
-	return "$Id: serv_imap.c 6333 2008-05-28 00:26:36Z davew $";
+	return "$Id: serv_imap.c 6453 2008-07-17 19:50:29Z ajc $";
 }
