@@ -1,5 +1,5 @@
 /*
- * $Id: serv_openid_rp.c 6375 2008-06-10 02:31:56Z ajc $
+ * $Id: serv_openid_rp.c 6495 2008-08-11 19:57:40Z ajc $
  *
  * This is an implementation of OpenID 1.1 Relying Party support, in stateless mode.
  *
@@ -254,20 +254,12 @@ void populate_vcard_from_sreg(HashList *sreg_keys) {
 
 	/* Only save the vCard if there is some useful data in it */
 	if (pop > 0) {
-		char temp[PATH_MAX];
-		FILE *fp;
 		char *ser;
-	
-		CtdlMakeTempFileName(temp, sizeof temp);
 		ser = vcard_serialize(v);
 		if (ser) {
-			fp = fopen(temp, "w");
-			if (fp) {
-				fwrite(ser, strlen(ser), 1, fp);
-				fclose(fp);
-				CtdlWriteObject(USERCONFIGROOM,	"text/x-vcard", temp, &CC->user, 0, 0, 0);
-				unlink(temp);
-			}
+			CtdlWriteObject(USERCONFIGROOM,	"text/x-vcard",
+				ser, strlen(ser)+1, &CC->user, 0, 0, 0
+			);
 			free(ser);
 		}
 	}
@@ -901,5 +893,5 @@ CTDL_MODULE_INIT(openid_rp)
 	}
 
 	/* return our Subversion id for the Log */
-	return "$Id: serv_openid_rp.c 6375 2008-06-10 02:31:56Z ajc $";
+	return "$Id: serv_openid_rp.c 6495 2008-08-11 19:57:40Z ajc $";
 }
