@@ -1,5 +1,5 @@
 /*
- * $Id: serv_vcard.c 6339 2008-05-28 17:17:21Z davew $
+ * $Id: serv_vcard.c 6495 2008-08-11 19:57:40Z ajc $
  * 
  * A server-side module for Citadel which supports address book information
  * using the standard vCard format.
@@ -794,22 +794,13 @@ struct vCard *vcard_get_user(struct ctdluser *u) {
  * Write our config to disk
  */
 void vcard_write_user(struct ctdluser *u, struct vCard *v) {
-	char temp[PATH_MAX];
-	FILE *fp;
 	char *ser;
 
-	CtdlMakeTempFileName(temp, sizeof temp);
 	ser = vcard_serialize(v);
-
-	fp = fopen(temp, "w");
-	if (fp == NULL) return;
 	if (ser == NULL) {
-		fprintf(fp, "begin:vcard\r\nend:vcard\r\n");
-	} else {
-		fwrite(ser, strlen(ser), 1, fp);
-		free(ser);
+		ser = strdup("begin:vcard\r\nend:vcard\r\n");
 	}
-	fclose(fp);
+	if (!ser) return;
 
 	/* This handy API function does all the work for us.
 	 * NOTE: normally we would want to set that last argument to 1, to
@@ -817,15 +808,16 @@ void vcard_write_user(struct ctdluser *u, struct vCard *v) {
 	 * have to, because the vcard_upload_beforesave() hook above
 	 * is going to notice what we're trying to do, and delete the old vCard.
 	 */
-	CtdlWriteObject(USERCONFIGROOM,	/* which room */
-			VCARD_MIME_TYPE,/* MIME type */
-			temp,		/* temp file */
-			u,		/* which user */
-			0,		/* not binary */
-			0,		/* don't delete others of this type */
-			0);		/* no flags */
+	CtdlWriteObject(USERCONFIGROOM,		/* which room */
+			VCARD_MIME_TYPE,	/* MIME type */
+			ser,			/* data */
+			strlen(ser)+1,		/* length */
+			u,			/* which user */
+			0,			/* not binary */
+			0,			/* don't delete others of this type */
+			0);			/* no flags */
 
-	unlink(temp);
+	free(ser);
 }
 
 
@@ -996,10 +988,14 @@ void vcard_newuser(struct ctdluser *usbuf) {
 	/* If using host auth mode, we add an email address based on the login */
 	if (config.c_auth_mode == AUTHMODE_HOST) {
 		struct passwd pwd;
-		struct passwd **result = NULL;
 		char pwd_buffer[SIZ];
-
+		
+#ifdef SOLARIS_GETPWUID
+		if (getpwuid_r(usbuf->uid, &pwd, pwd_buffer, sizeof pwd_buffer) != NULL) {
+#else // SOLARIS_GETPWUID
+		struct passwd **result = NULL;
 		if (getpwuid_r(usbuf->uid, &pwd, pwd_buffer, sizeof pwd_buffer, result) == 0) {
+#endif // HAVE_GETPWUID_R
 			snprintf(buf, sizeof buf, "%s@%s", pwd.pw_name, config.c_fqdn);
 			vcard_add_prop(v, "email;internet", buf);
 		}
@@ -1606,5 +1602,5 @@ CTDL_MODULE_INIT(vcard)
 	}
 	
 	/* return our Subversion id for the Log */
-	return "$Id: serv_vcard.c 6339 2008-05-28 17:17:21Z davew $";
+	return "$Id: serv_vcard.c 6495 2008-08-11 19:57:40Z ajc $";
 }
