@@ -1,4 +1,4 @@
-/* $Id: msgbase.h 6326 2008-05-25 19:01:17Z davew $ */
+/* $Id: msgbase.h 6495 2008-08-11 19:57:40Z ajc $ */
 
 #ifndef MSGBASE_H
 #define MSGBASE_H
@@ -119,8 +119,15 @@ int CtdlForEachMessage(int mode,
                         void (*CallBack) (long, void *),
 			void *userdata);
 int CtdlDeleteMessages(char *, long *, int, char *);
-void CtdlWriteObject(char *, char *, char *, struct ctdluser *,
-			int, int, unsigned int);
+void CtdlWriteObject(char *req_room,			/* Room to stuff it in */
+			char *content_type,		/* MIME type of this object */
+			char *raw_message,		/* Data to be written */
+			off_t raw_length,		/* Size of raw_message */
+			struct ctdluser *is_mailbox,	/* Mailbox room? */
+			int is_binary,			/* Is encoding necessary? */
+			int is_unique,			/* Del others of this type? */
+			unsigned int flags		/* Internal save flags */
+);
 struct CtdlMessage *CtdlFetchMessage(long msgnum, int with_body);
 void CtdlFreeMessage(struct CtdlMessage *msg);
 void serialize_message(struct ser_ret *, struct CtdlMessage *);
