@@ -1,5 +1,5 @@
 /*
- * $Id: sysdep.c 6335 2008-05-28 13:23:43Z davew $
+ * $Id: sysdep.c 6452 2008-07-17 19:03:00Z davew $
  *
  * Citadel "system dependent" stuff.
  * See copyright.txt for copyright information.
@@ -72,6 +72,7 @@
 #include "ctdl_module.h"
 #include "threads.h"
 #include "user_ops.h"
+#include "control.h"
 
 
 #ifdef DEBUG_MEMORY_LEAKS
@@ -98,6 +99,52 @@ int syslog_facility = LOG_DAEMON;
 int enable_syslog = 0;
 
 
+/* Flag for single user mode */
+static int want_single_user = 0;
+
+/* Try to go single user */
+
+int CtdlTrySingleUser(void)
+{
+	int can_do = 0;
+	
+	begin_critical_section(S_SINGLE_USER);
+	if (want_single_user)
+		can_do = 0;
+	else
+	{
+		can_do = 1;
+		want_single_user = 1;
+	}
+	end_critical_section(S_SINGLE_USER);
+	return can_do;
+}
+
+void CtdlEndSingleUser(void)
+{
+	begin_critical_section(S_SINGLE_USER);
+	want_single_user = 0;
+	end_critical_section(S_SINGLE_USER);
+}
+
+
+int CtdlWantSingleUser(void)
+{
+	return want_single_user;
+}
+
+int CtdlIsSingleUser(void)
+{
+	if (want_single_user)
+	{
+		/* check for only one context here */
+		if (num_sessions == 1)
+			return TRUE;
+	}
+	return FALSE;
+}
+
+
 /*
  * CtdlLogPrintf()  ...   Write logging information
  */
@@ -423,13 +470,11 @@ struct CitContext *CreateNewContext(void) {
 		return NULL;
 	}
 
-	/* We can fill this as though its a private context but we must clear the internal_pgm flag
-	 * to keep things correct. Watch out for the cs_pid field, that gets set further down,
-	 * make sure you don't try to do it first.
-	 */
-	CtdlFillPrivateContext(me, "notauth");
-	me->internal_pgm = 0;
-
+	memset(me, 0, sizeof(struct CitContext));
+	
+	/* Give the contaxt a name. Hopefully makes it easier to track */
+	strcpy (me->user.fullname, "SYS_notauth");
+	
 	/* The new context will be created already in the CON_EXECUTING state
 	 * in order to prevent another thread from grabbing it while it's
 	 * being set up.
@@ -474,9 +519,10 @@ struct CitContext *CtdlGetContextArray(int *count)
 
 
 /**
- * This function fille in a context and its user field correctly
+ * This function fills in a context and its user field correctly
+ * Then creates/loads that user
  */
-void CtdlFillPrivateContext(struct CitContext *context, char *name)
+void CtdlFillSystemContext(struct CitContext *context, char *name)
 {
 	char sysname[USERNAME_SIZE];
 
@@ -485,10 +531,19 @@ void CtdlFillPrivateContext(struct CitContext *context, char *name)
 	context->cs_pid = 0;
 	strcpy (sysname, "SYS_");
 	strcat (sysname, name);
-	if (getuser(&(context->user), sysname))
-	{
-		strcpy(context->user.fullname, sysname);
+	/* internal_create_user has the side effect of loading the user regardless of wether they
+	 * already existed or needed to be created
+	 */
+	internal_create_user (sysname, &(context->user), -1) ;
+	
+	/* Check to see if the system user needs upgrading */
+	if (context->user.usernum == 0)
+	{	/* old system user with number 0, upgrade it */
+		context->user.usernum = get_new_user_number();
+		CtdlLogPrintf(CTDL_DEBUG, "Upgrading system user \"%s\" from user number 0 to user number %d\n", context->user.fullname, context->user.usernum);
+		/* add user to the database */
 		putuser(&(context->user));
+		cdb_store(CDB_USERSBYNUMBER, &(context->user.usernum), sizeof(long), context->user.fullname, strlen(context->user.fullname)+1);
 	}
 }
 
